obs_pairs_mtsl: Expected number of observed pairs assuming multiple-transmission and single-linkage
Description
This function calculates the expected number of pairs observed in a sample of size M.
The multiple-transmission and single-linkage method assumes the following:
Each case \(i\) is, on average, the infector of R cases in the population (\(N\))
Each case \(i\) is allowed to be linked by the linkage criteria to only one other case \(j\) in the sampled population (\(M\)).
Usage
obs_pairs_mtsl(chi, eta, rho, M, R)
Value
scalar or vector giving the expected number of linked pairs observed in the sample
Arguments
chi
scalar or vector giving the specificity of the linkage criteria
eta
scalar or vector giving the sensitivity of the linkage criteria
rho
scalar or vector giving the proportion of the final outbreak size that is sampled
M
scalar or vector giving the number of cases sampled
R
scalar or vector giving the effective reproductive number of the pathogen
Author
John Giles, Shirlee Wohl and Justin Lessler
See Also
Other obs_pairs:
exp_links(),
obs_pairs_mtml(),
obs_pairs_stsl()