obs_pairs_stsl: Expected number of observed pairs assuming single-transmission and single-linkage
Description
This function calculates the expected number of link pairs observed in a sample of size M.
The single-transmission and single-linkage method assumes the following:
Each case \(i\) is linked by transmission to only one other case \(j\) in the population (\(N\)).
Each case \(i\) is linked by the linkage criteria to only one other case \(j\) in the sampled population (\(M\)).
Usage
obs_pairs_stsl(eta, chi, rho, M)
Value
scalar or vector giving the expected number of linked pairs observed in the sample
Arguments
eta
scalar or vector giving the sensitivity of the linkage criteria
chi
scalar or vector giving the specificity of the linkage criteria
rho
scalar or vector giving the proportion of the final outbreak size that is sampled
M
scalar or vector giving the number of cases sampled
Author
John Giles, Shirlee Wohl, and Justin Lessler
See Also
Other obs_pairs:
exp_links(),
obs_pairs_mtml(),
obs_pairs_mtsl()