Learn R Programming

phylosamp (version 1.0.1)

phylosamp-package: phylosamp: Sample Size Calculations for Molecular and Phylogenetic Studies

Description

Implements novel tools for estimating sample sizes needed for phylogenetic studies, including studies focused on estimating the probability of true pathogen transmission between two cases given phylogenetic linkage and studies focused on tracking pathogen variants at a population level. Methods described in Wohl, Giles, and Lessler (2021) and in Wohl, Lee, DiPrete, and Lessler (2023).

Arguments

Author

Maintainer: Justin Lessler jlessler@unc.edu

Authors:

See Also