Learn R Programming

phylosamp (version 1.0.1)

translink_expected_links_true: Calculate expected number of true transmission pairs

Description

This function calculates the expected number true transmission pairs in a sample of size M. Assumptions about transmission and linkage (single or multiple) can be specified.

Usage

translink_expected_links_true(
  sensitivity,
  rho,
  M,
  R = NULL,
  assumption = "mtml"
)

Value

scalar or vector giving the expected number of true transmission pairs in the sample

Arguments

sensitivity

scalar or vector giving the sensitivity of the linkage criteria

rho

scalar or vector giving the proportion of the final outbreak size that is sampled

M

scalar or vector giving the number of cases sampled

R

scalar or vector giving the effective reproductive number of the pathogen (default=NULL)

assumption

a character vector indicating which assumptions about transmission and linkage criteria. Default = 'mtml'. Accepted arguments are:

  1. 'stsl' for the single-transmission single-linkage assumption.

  2. 'mtsl' for the multiple-transmission single-linkage assumption.

  3. 'mtml' for the multiple-transmission multiple-linkage assumption.

Author

John Giles, Shirlee Wohl, and Justin Lessler

See Also

Other transmission linkage functions: translink_expected_links_obs_mtml(), translink_expected_links_obs_mtsl(), translink_expected_links_obs_stsl(), translink_expected_links_obs(), translink_expected_links_true_mtml(), translink_expected_links_true_mtsl(), translink_expected_links_true_stsl(), translink_fdr(), translink_prob_transmit_mtml(), translink_prob_transmit_mtsl(), translink_prob_transmit_stsl(), translink_prob_transmit(), translink_samplesize(), translink_tdr()

Examples

Run this code
translink_expected_links_true(sensitivity=0.99, rho=0.75, M=100, R=1)

Run the code above in your browser using DataLab