Learn R Programming

phylosamp (version 1.0.1)

true_pairs: Calculate expected number of true transmission pairs

Description

[Deprecated] This function calculates the expected number true transmission pairs in a sample of size M. Assumptions about transmission and linkage (single or multiple) can be specified.

Usage

true_pairs(eta, rho, M, R = NULL, assumption = "mtml")

Value

scalar or vector giving the expected number of true transmission pairs in the sample

Arguments

eta

scalar or vector giving the sensitivity of the linkage criteria

rho

scalar or vector giving the proportion of the final outbreak size that is sampled

M

scalar or vector giving the number of cases sampled

R

scalar or vector giving the effective reproductive number of the pathogen (default=NULL)

assumption

a character vector indicating which assumptions about transmission and linkage criteria. Default = 'mtml'. Accepted arguments are:

  1. 'stsl' for the single-transmission single-linkage assumption (prob_trans_stsl()).

  2. 'mtsl' for the multiple-transmission single-linkage assumption (prob_trans_mtsl()).

  3. 'mtml' for the multiple-transmission multiple-linkage assumption (prob_trans_mtml()).

Author

John Giles, Shirlee Wohl, and Justin Lessler

See Also

Other true_pairs: true_pairs_mtml(), true_pairs_mtsl(), true_pairs_stsl()

Examples

Run this code
true_pairs(eta=0.99, rho=0.75, M=100, R=1)

Run the code above in your browser using DataLab