Learn R Programming

phylosamp (version 1.0.1)

truediscoveryrate: Calculate true discovery rate of a sample

Description

[Deprecated] This function calculates the true discovery rate (proportion of true transmission pairs) in a sample given the sensitivity \(\eta\) and specificity \(\chi\) of the linkage criteria, and sample size \(M\). Assumptions about transmission and linkage (single or multiple) can be specified.

Usage

truediscoveryrate(eta, chi, rho, M, R = NULL, assumption = "mtml")

Value

scalar or vector giving the true discovery rate

Arguments

eta

scalar or vector giving the sensitivity of the linkage criteria

chi

scalar or vector giving the specificity of the linkage criteria

rho

scalar or vector giving the proportion of the final outbreak size that is sampled

M

scalar or vector giving the number of cases sampled

R

scalar or vector giving the effective reproductive number of the pathogen (default=NULL)

assumption

a character vector indicating which assumptions about transmission and linkage criteria. Default = 'mtml'. Accepted arguments are:

  1. 'stsl' for the single-transmission single-linkage assumption (prob_trans_stsl()).

  2. 'mtsl' for the multiple-transmission single-linkage assumption (prob_trans_mtsl()).

  3. 'mtml' for the multiple-transmission multiple-linkage assumption (prob_trans_mtml()).

Author

John Giles, Shirlee Wohl, and Justin Lessler

See Also

Other discovery_rate: falsediscoveryrate()

Examples

Run this code
# The simplest case: single-transmission, single-linkage, and perfect sensitivity
truediscoveryrate(eta=1, chi=0.9, rho=0.5, M=100, assumption='stsl')

# Multiple-transmission and imperfect sensitivity
truediscoveryrate(eta=0.99, chi=0.9, rho=1, M=50, R=1, assumption='mtsl')

# Small outbreak, larger sampling proportion
truediscoveryrate(eta=0.99, chi=0.95, rho=1, M=50, R=1, assumption='mtml')

# Large outbreak, small sampling proportion
truediscoveryrate(eta=0.99, chi=0.95, rho=0.5, M=1000, R=1, assumption='mtml')

Run the code above in your browser using DataLab