varfreq_cdf_logistic: Calculate cumulative observed variant prevalence at time t given logistic growth
Description
This function calculates the cumulative observed variant prevalence after t time steps (e.g., days)
given a logistic growth rate and initial variant prevalence.
Usage
varfreq_cdf_logistic(t, p0_v1, r_v1, c_ratio = 1)
Value
scalar giving the cdf of variant prevalence at time t
Arguments
t
time step number (e.g., days) at which to calculate prevalence
p0_v1
initial variant prevalence (# introductions / infected population size)
r_v1
logistic growth rate
c_ratio
coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2. Default = 1 (no bias)
Author
Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler
See Also
Other logistic growth functions:
varfreq_freq_logistic()
Other variant frequency functions:
varfreq_expected_mbias(),
varfreq_freq_logistic(),
varfreq_obs_freq()