powered by
This function calculates the observed variant prevalence after t time steps (e.g., days) given a logistic growth rate and initial variant prevalence.
varfreq_freq_logistic(t, p0_v1, r_v1, c_ratio = 1)
scalar giving the variant prevalence at time t
time step number (e.g., days) at which to calculate prevalence
initial variant prevalence (# introductions / infected population size)
logistic growth rate
coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2; default = 1 (no bias)
Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler
Other logistic growth functions: varfreq_cdf_logistic()
varfreq_cdf_logistic()
Other variant frequency functions: varfreq_cdf_logistic(), varfreq_expected_mbias(), varfreq_obs_freq()
varfreq_expected_mbias()
varfreq_obs_freq()
varfreq_freq_logistic(t = 30, p0_v1 = 1/10000, r_v1 = 0.1, c_ratio = 1)
Run the code above in your browser using DataLab