Learn R Programming

phylosamp (version 1.0.1)

varfreq_obs_freq: Calculate observed variant prevalence

Description

This function calculates the observed variant prevalence from the coefficient of detection ratio and the actual variant prevalence. This function assumes that variant 1 is the variant of concern. This function is specific to the two-variant system.

Usage

varfreq_obs_freq(p_v1, c_ratio)

Value

scalar of observed prevalence of variant 1

Arguments

p_v1

actual variant prevalence (proportion)

c_ratio

coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2

Author

Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler

See Also

Other variant frequency functions: varfreq_cdf_logistic(), varfreq_expected_mbias(), varfreq_freq_logistic()

Examples

Run this code
varfreq_obs_freq(p_v1 = 0.1, c_ratio = 1.1)

Run the code above in your browser using DataLab