Learn R Programming

phylosamp (version 1.0.1)

vartrack_prob_prev: Calculate confidence in a variant estimate given a sample size

Description

This function calculates the probability of accurately estimating variant prevalence given a sample size and desired precision in the variant prevalence estimate. Currently, only cross-sectional sampling is supported.

Usage

vartrack_prob_prev(p_v1, n, omega, precision, c_ratio = 1, sampling_freq)

Value

scalar of expected sample size

Arguments

p_v1

variant prevalence (proportion)

n

sample size

omega

probability of sequencing (or other characterization) success

precision

desired precision in variant prevalence estimate

c_ratio

coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2. Default = 1 (no bias)

sampling_freq

the sampling frequency (must be either 'xsect' in current implementation)

Author

Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler

See Also

Other variant prevalence estimation functions: vartrack_prob_prev_xsect(), vartrack_samplesize_prev_xsect(), vartrack_samplesize_prev()

Other variant tracking functions: vartrack_cod_ratio(), vartrack_prob_detect_cont(), vartrack_prob_detect_xsect(), vartrack_prob_detect(), vartrack_prob_prev_xsect(), vartrack_samplesize_detect_cont(), vartrack_samplesize_detect_xsect(), vartrack_samplesize_detect(), vartrack_samplesize_prev_xsect(), vartrack_samplesize_prev()

Examples

Run this code
vartrack_prob_prev(p_v1 = 0.1, n = 200, omega = 0.8, precision = 0.1, 
c_ratio = 1, sampling_freq = 'xsect')

Run the code above in your browser using DataLab