Learn R Programming

phylosamp (version 1.0.1)

vartrack_samplesize_detect: Calculate sample size needed for variant detection given a desired probability of detection

Description

This function calculates the sample size needed for detecting the presence of a variant given a desired probability of detection and sampling strategy.

Usage

vartrack_samplesize_detect(
  prob,
  t = NA,
  p_v1 = NA,
  omega,
  p0_v1 = NA,
  r_v1 = NA,
  c_ratio = 1,
  sampling_freq
)

Value

scalar of expected sample size

Arguments

prob

desired probability of detection

t

time step number (e.g., days) at which variant should be detected by. Default = NA (either 't' or 'p_v1' should be provided, not both)

p_v1

the desired prevalence to detect a variant by. Default = NA (either 't' or 'p_v1' should be provided, not both)

omega

probability of sequencing (or other characterization) success

p0_v1

initial variant prevalence (# introductions / infected population size)

r_v1

logistic growth rate

c_ratio

coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2. Default = 1 (no bias)

sampling_freq

the sampling frequency (must be either 'xsect' or 'cont')

Author

Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler

See Also

Other variant detection functions: vartrack_prob_detect_cont(), vartrack_prob_detect_xsect(), vartrack_prob_detect(), vartrack_samplesize_detect_cont(), vartrack_samplesize_detect_xsect()

Other variant tracking functions: vartrack_cod_ratio(), vartrack_prob_detect_cont(), vartrack_prob_detect_xsect(), vartrack_prob_detect(), vartrack_prob_prev_xsect(), vartrack_prob_prev(), vartrack_samplesize_detect_cont(), vartrack_samplesize_detect_xsect(), vartrack_samplesize_prev_xsect(), vartrack_samplesize_prev()

Examples

Run this code
# Cross-sectional sampling
vartrack_samplesize_detect(p_v1 = 0.1, prob = 0.95, omega = 0.8,
                           c_ratio = 1, sampling_freq = 'xsect')

# Periodic sampling
vartrack_samplesize_detect(prob = 0.95, t = 30, omega = 0.8, p0_v1 = 1/10000,
                           r_v1 = 0.1, c_ratio = 1, sampling_freq = 'cont')

Run the code above in your browser using DataLab