Learn R Programming

phylosamp (version 1.0.1)

vartrack_samplesize_prev: Calculate sample size needed for estimating variant prevalence given a desired confidence

Description

This function calculates the sample size needed for estimating variant prevalence given a desired confidence and desired precision in the variant prevalence estimate. Currently, only cross-sectional sampling is supported.

Usage

vartrack_samplesize_prev(
  p_v1,
  prob,
  precision,
  omega,
  c_ratio = 1,
  sampling_freq
)

Value

scalar of sample size

Arguments

p_v1

variant prevalence (proportion)

prob

desired confidence in variant prevalence estimate

precision

desired precision in variant prevalence estimate

omega

probability of sequencing (or other characterization) success

c_ratio

coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2. Default = 1 (no bias)

sampling_freq

the sampling frequency (must be 'xsect' in current implementation)

Author

Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler

See Also

Other variant prevalence estimation functions: vartrack_prob_prev_xsect(), vartrack_prob_prev(), vartrack_samplesize_prev_xsect()

Other variant tracking functions: vartrack_cod_ratio(), vartrack_prob_detect_cont(), vartrack_prob_detect_xsect(), vartrack_prob_detect(), vartrack_prob_prev_xsect(), vartrack_prob_prev(), vartrack_samplesize_detect_cont(), vartrack_samplesize_detect_xsect(), vartrack_samplesize_detect(), vartrack_samplesize_prev_xsect()

Examples

Run this code
vartrack_samplesize_prev(p_v1 = 0.1, prob = 0.95, precision = 0.25, 
omega = 0.8, c_ratio = 1, sampling_freq = 'xsect')

Run the code above in your browser using DataLab