This function calculates the expected number true transmission pairs in a sample of size M.
Assumptions about transmission and linkage (single or multiple) can be specified.
translink_expected_links_true(
sensitivity,
rho,
M,
R = NULL,
assumption = "mtml"
)scalar or vector giving the expected number of true transmission pairs in the sample
scalar or vector giving the sensitivity of the linkage criteria
scalar or vector giving the proportion of the final outbreak size that is sampled
scalar or vector giving the number of cases sampled
scalar or vector giving the effective reproductive number of the pathogen (default=NULL)
a character vector indicating which assumptions about transmission and linkage criteria. Default = 'mtml'. Accepted arguments are:
'stsl' for the single-transmission single-linkage assumption.
'mtsl' for the multiple-transmission single-linkage assumption.
'mtml' for the multiple-transmission multiple-linkage assumption.
John Giles, Shirlee Wohl, and Justin Lessler
Other transmission linkage functions:
translink_expected_links_obs_mtml(),
translink_expected_links_obs_mtsl(),
translink_expected_links_obs_stsl(),
translink_expected_links_obs(),
translink_expected_links_true_mtml(),
translink_expected_links_true_mtsl(),
translink_expected_links_true_stsl(),
translink_fdr(),
translink_prob_transmit_mtml(),
translink_prob_transmit_mtsl(),
translink_prob_transmit_stsl(),
translink_prob_transmit(),
translink_samplesize(),
translink_tdr()
translink_expected_links_true(sensitivity=0.99, rho=0.75, M=100, R=1)
Run the code above in your browser using DataLab