true_pairs_mtsl: Expected number of true transmission pairs assuming multiple-transmission and single-linkage
Description
This function calculates the expected number true transmission pairs in a sample of size M.
The multiple-transmission and single-linkage method assumes the following:
Each case \(i\) is, on average, the infector of R cases in the population (\(N\))
Each case \(i\) is allowed to be linked by the linkage criteria to only one other case \(j\) in the sampled population (\(M\)).
Usage
true_pairs_mtsl(eta, rho, M, R)
Value
scalar or vector giving the expected number of true transmission pairs in the sample
Arguments
eta
scalar or vector giving the sensitivity of the linkage criteria
rho
scalar or vector giving the proportion of the final outbreak size that is sampled
M
scalar or vector giving the number of cases sampled
R
scalar or vector giving the effective reproductive number of the pathogen
Author
John Giles, Shirlee Wohl and Justin Lessler
See Also
Other true_pairs:
true_pairs_mtml(),
true_pairs_stsl(),
true_pairs()