varfreq_expected_mbias: Calculate multiplicative bias (observed / actual) in variant prevalence
Description
This function calculates the multiplicative bias of the observed variant proportion
relative to the actual variant proportion. This function assumes that variant 1 is the variant of concern.
This function is specific to the two-variant system.
Usage
varfreq_expected_mbias(p_v1, c_ratio)
Value
scalar giving the multiplicative bias of variant 1
Arguments
p_v1
actual variant prevalence (proportion)
c_ratio
coefficient of detection ratio, calculated as the ratio of the coefficients of variant 1 to variant 2
Author
Shirlee Wohl, Elizabeth C. Lee, Bethany L. DiPrete, and Justin Lessler
See Also
Other variant frequency functions:
varfreq_cdf_logistic(),
varfreq_freq_logistic(),
varfreq_obs_freq()